Bun v1.4.4
Fixes 271 issues, addressing 544 👍. bun fmt, a Prettier-compatible formatter built into Bun that is 3x to 6x faster than oxfmt, bun check is 1.4x to 7.8x faster on large projects, bun install migrates Yarn Berry lockfiles, retries with exponential backoff and closes 133 issues, up to 3.2x faster hoisted installs from a warm cache on Linux, bun pm fetch, bun publish --recursive, packageExtensions, Bun.SQL uses up to 48% less CPU per query, query.cancel(), COPY streams, column name transforms, user-defined functions and update hooks in bun:sqlite, ws rewritten to behave like npm ws on Node.js, ws.pause() and ws.resume() in Bun.serve, a JavaScriptCore upgrade with 54x faster toLocaleString, up to 2.8x faster Headers iteration, up to 2.6x faster response.body streams, extglob and brace ranges in Bun.Glob, a redesigned error overlay in the dev server, and many bugfixes and Node.js compatibility improvements.